#! /bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre installation file for lynx on EIS/FAIR
#
# Copyright (c) 2009-2019  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2009-10-29  jed
# Last Update:  $Id: preinstall.sh 70026 2019-10-25 15:41:48Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# file names
pgmname=`basename $0`
module_name='lynx'

# extract shared library file from archive
# to be able to use the myecho command
archivefile=`find /tmp -maxdepth 1 -type l -name "${module_name}.tar.*" ! -name "*.info" | head -n1`

if [ -n "${archivefile}" ]
then
    if [ -s "${archivefile}" ]
    then
        tar xjf ${archivefile} var/install/include/jedlib.${module_name} -C /

        srcfile=/var/install/include/jedlib.${module_name}
        destfile=/var/install/include/jedlib

        if [ -f ${srcfile} ]
        then
            if [ -f ${destfile} ]
            then
                srcver=`/bin/sh ${srcfile} version`
                destver=`/bin/sh ${destfile} version`

                if [ -n "${destver}" ]
                then
                    # version number exists - compare version numbers
                    if [ `echo "${srcver} > ${destver}" | bc` -eq 1 ]
                    then
                        # update file
                        echo "updating shared library file (${destver}->${srcver}) ..."
                        mv -v ${srcfile} ${destfile}
                    fi
                else
                    # no version number exists - update file
                    echo "updating shared library file ..."
                    mv -v ${srcfile} ${destfile}
                fi
            else
                # file doesn't exist - update file
                echo "updating shared library file ..."
                mv -v ${srcfile} ${destfile}
            fi
        fi
    fi
fi

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

myecho --pack ${module_name} --info "running preinstall.sh ..."

# check lynx version
installed_version=`/usr/bin/eisman check lynx 0.90.1`

case $installed_version in
    new ) # wrong version
        myecho --pack ${module_name} --info "old lynx package < v0.90.1 found, removing files..."

        for FNAME in /usr/bin/lynx /usr/bin/lynx-color /usr/lib/lynx.cfg /usr/share/locale/cs/LC_MESSAGES/lynx.mo /usr/share/locale/da/LC_MESSAGES/lynx.mo /usr/share/locale/de/LC_MESSAGES/lynx.mo /usr/share/locale/ja/LC_MESSAGES/lynx.mo /usr/share/locale/nl/LC_MESSAGES/lynx.mo /usr/share/locale/pt_BR/LC_MESSAGES/lynx.mo /usr/share/locale/ru/LC_MESSAGES/lynx.mo /usr/share/locale/sl/LC_MESSAGES/lynx.mo /usr/share/locale/sv/LC_MESSAGES/lynx.mo /usr/share/man/man1/lynx.1.gz /var/install/packages/lynx
        do
            rm -fv ${FNAME}
        done

        rm -fRv /usr/share/doc/packages/lynx

        myecho --pack ${module_name} "done."
        myanykey --pack ${module_name}
        ;;
    * ) # not-installed / installed / old
        ;;
esac

# deinstall old software
myecho --pack ${module_name} "deinstalling previously installed software ..."
/usr/bin/eisman uninstall --update --auto --quiet ${module_name}

exit 0
