#!/bin/sh
#-------------------------------------------------------------------------------
# /etc/config.d/lynx.sh - configuration generator script
#
# Copyright (c) 2018-2019  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2018-08-22  jed
# Last Update:  $Id: lynx.sh 70026 2019-10-25 15:41:48Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#-------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2>/tmp/$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

pgmname=`basename $0`
module_name=`basename -s .sh ${pgmname} | cut -d- -f1`

### set directory and file names ###
config_file_std=/etc/${module_name}.cfg.std
config_file=/etc/${module_name}.cfg
auth_file=/root/.lynx_auth.cfg

### other parameters ###
if [ "`/usr/bin/eisman check ${module_name}`" = 'installed' ]
then
    lynx_version="`/usr/bin/eisman query --installed --fields=version --no-tty ${module_name} | sed -e '/^version/!d' -e 's/^version *//' | tail -n1`"
else
    lynx_version='unknown'
fi

#----------------------------------------------------------------------------------------
# generate configuration
#----------------------------------------------------------------------------------------
generate_config ()
{
    myecho --pack ${module_name} "creating ${module_name} configuration file ..."

    {
        #----------------------------------------------------------------------------
        print_short_header "${config_file}" "${pgmname}" "${module_name}" "v${lynx_version}"
        #----------------------------------------------------------------------------

        . /etc/config.d/environment

        cat ${config_file_std}

        if [ -n "${HTTP_PROXY}" ]
        then
            # http proxy
            echo "http_proxy:http://`echo "${HTTP_PROXY}" | sed -e 's#^http[s]*://##' -e 's#/$##'`/"
            echo "https_proxy:https://`echo "${HTTP_PROXY}" | sed -e 's#^http[s]*://##' -e 's#/$##'`/"
        fi
    } > ${config_file}

    if [ -n "${HTTP_PROXY_USER}" ]
    then
        # http authentication - The credentials need to be written to a file
        #     and parsed via command line to the lynx binary because otherwise
        #     each page request would require a reconfirmation of it.
        {
            echo "http_proxy_user=${HTTP_PROXY_USER}"
            echo "http_proxy_pass=${HTTP_PROXY_PASSWD}"
        } > ${auth_file}

        chmod 0600 ${auth_file}
    else
        rm -f ${auth_file}
    fi
}

#========================================================================================
# main
#========================================================================================

force_quiet_run=false
if [ $# -gt 0 ]
then
    # read parameter(s)
    while [ $# -gt 0 ]
    do
        case $1 in
            *-quiet )
                force_quiet_run=true
                shift
                ;;
            * )
                cmd="$1"
                break
                ;;
        esac
    done
fi

case ${cmd} in
    * )
        # generate all configuration files
        myecho --pack ${module_name} ""
        myecho --pack ${module_name} "${module_name} version: ${lynx_version}"

        generate_config
        ;;
esac

#========================================================================================
# End
#========================================================================================
exit 0
